@@ -1,6 +1,6 @@
 import functools
 import weakref
-from typing import Any, Callable, Type, TypeVar, Union, cast
+from typing import Any, Callable, Optional, Type, TypeVar, Union, cast
 from typing_extensions import Protocol
 '''
 Typing this library correctly is impossible right now.
@@ -46,14 +46,21 @@ class cached_property(property, _Property[SELF, OUT]):
     '''decorator for converting a method into a cached property'''
 
     # https://stackoverflow.com/a/4037979/3671939
+    # setattr(instance, name, value) raises
+    #   AttributeError: Can't set attribute.
+    # Using my own caching system with "self._cache"
+
+    _cache: OUT
 
     def __init__(self, method: Callable[[SELF], OUT]):
-        self._method = method
+        self._method: Optional[Callable[[SELF], OUT]] = method
 
     def __get__(self, instance: SELF, _) -> OUT:
-        value = self._method(instance)
-        setattr(instance, self._method.__name__, value)
-        return value
+        if self._method is None:
+            return self._cache
+        self._cache = self._method(instance)
+        self._method = None
+        return self._cache
 
 
 def set_method(cls):
